@@ -252,6 +252,11 @@ class DatasetManifest:
         Sample a few-shot dataset, with the number of images per class below num_samples_per_class.
         For multiclass dataset, this is always possible, while for multilabel dataset, it is not guaranteed
         Multitask dataset and detection dataset are treated the same with multilabel dataset.
+
+        This method tries to get balanced results.
+
+        Note that negative images will be added to the subset up to num_samples_per_class.
+
         Args:
             num_samples_per_class: rough number samples per class to sample
             random_seed: random seed
@@ -324,30 +329,32 @@ class DatasetManifest:
         sampled_images = [self.images[i] for i in sampled_image_ids]
         return DatasetManifest(sampled_images, self.labelmap, self.data_type)
 
-    def sample_few_shots_subset_greedy(self, n_shots, random_seed=0):
+    def sample_few_shots_subset_greedy(self, num_min_samples_per_class, random_seed=0):
         """Greedy few-shots sampling method.
-        Randomly pick images from the original datasets until all classes have at least n_shots images.
+        Randomly pick images from the original datasets until all classes have at least {num_min_images_per_class} tags/boxes.
+
+        Note that images without any tag/box will be ignored. All images in the subset will have at least one tag/box.
 
         Args:
-            n_shots (int): The number of images per class.
+            num_min_samples_per_class (int): The minimum number of samples per class.
             random_seed (int): Random seed to use.
 
         Returns:
             A samped dataset (DatasetManifest)
 
         Raises:
-            RuntimeError if it couldn't find n_shots images.
+            RuntimeError if it couldn't find num_min_samples_per_class samples for all classes
         """
-        assert n_shots > 0
+        assert num_min_samples_per_class > 0
         images = list(self.images)
         rng = random.Random(random_seed)
         rng.shuffle(images)
 
         num_classes = len(self.labelmap) if not self.is_multitask else sum(len(x) for x in self.labelmap.values())
-        total_counter = collections.Counter({i: n_shots for i in range(num_classes)})
+        total_counter = collections.Counter({i: num_min_samples_per_class for i in range(num_classes)})
         sampled_images = []
         for image in images:
-            counts = collections.Counter(set([self._get_cid(c) for c in image.labels] if not self.is_multitask else [self._get_cid(c, t) for t, t_labels in image.labels.items() for c in t_labels]))
+            counts = collections.Counter([self._get_cid(c) for c in image.labels] if not self.is_multitask else [self._get_cid(c, t) for t, t_labels in image.labels.items() for c in t_labels])
             if set((+total_counter).keys()) & set(counts.keys()):
                 total_counter -= counts
                 sampled_images.append(image)
@@ -356,7 +363,7 @@ class DatasetManifest:
                 break
 
         if +total_counter:
-            raise RuntimeError(f"Couldn't find {n_shots} samples for some classes: {+total_counter}")
+            raise RuntimeError(f"Couldn't find {num_min_samples_per_class} samples for some classes: {+total_counter}")
 
         return DatasetManifest(sampled_images, self.labelmap, self.data_type)
 
